
===============================
Django Robotice Control Backend
===============================


Basic implementation of Django Auth Backend for Robotice Control.


Read More
---------

* https://docs.djangoproject.com/en/1.7/topics/auth/customizing/